*Replication do file to accompany "Citizen Perceptions of Government Service Quality: Evidence from Public Schools."
*Tested in Stata/MP 10.1

set mem 200m
set more off

*Set working directory here
cd "\\fpfsc05\UserData L-P\Users\MChingos\My Documents\AJPS paper\Replication\Send to AJPS"

*You will need to create a folder called "Out" in your working directory
*This is where outreg2 puts the analysis output

*Install outreg2 if you don't already have it installed
*ssc install outreg2

*ANALYSIS OF NATIONAL DATASET (TABLES 1, 2, A1, A2, AND FIGURE 1)
use national_file.dta, clear

*Divide variables by their standard deviation so that coefficients will corresponding to one-sd change in independent variable
foreach v in pblack phisp plunch prof gravg_adj ptr {
sum `v' [aweight=weight1] if pblack~=. & ptr~=. & prof~=.
replace `v' = `v'/r(sd)
}

*Generate interaction terms
gen profpar617 = prof*parent617
gen profown = prof*own

*TABLE 1 - Relationship Between School Characteristics and Respondents' Ratings
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1], absorb(STABBR) cluster(caseid)
outreg2 using Out/table1, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1], absorb(caseid) cluster(caseid)
outreg2 using Out/table1, excel br noaster bdec(3) sdec(3) rdec(3) nocons 
areg rate4 prof pblack phisp plunch gravg_adj ptr middle parent617 profpar617 [aweight=weight1], absorb(STABBR) cluster(caseid)
outreg2 using Out/table1, excel br noaster bdec(3) sdec(3) rdec(3) nocons 
areg rate4 prof pblack phisp plunch gravg_adj ptr middle own profown [aweight=weight1], absorb(STABBR) cluster(caseid)
outreg2 using Out/table1, excel br noaster bdec(3) sdec(3) rdec(3) nocons 
areg rate4 prof pblack phisp plunch gravg_adj ptr middle profpar617 profown [aweight=weight1], absorb(caseid) cluster(caseid)
outreg2 using Out/table1, excel br noaster bdec(3) sdec(3) rdec(3) nocons 

*TABLE 2 - Relationship Between Schools' Demographic Characteristics and Respondents' Ratings, by Respondent Characteristics
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight2] if black==1, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight2] if hisp==1, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight2] if white==1, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1] if inclt50==1, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1] if inclt50==0, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1] if parent617==1, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1] if parent617==0, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1] if own==1, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 prof pblack phisp plunch gravg_adj ptr middle [aweight=weight1] if own==0, absorb(STABBR) cluster(caseid)
outreg2 using Out/table2, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*TABLE A1 - Relationship Between School Characteristics and Respondents' School Ratings, Marginal Effects from Ordered Probit Models
xi i.STABBR
oprobit rate prof pblack phisp plunch gravg_adj ptr middle _IST* [pweight=weight1], cluster(caseid)
estimates store res
foreach i of numlist 1/5 {
	estimates restore res
	mfx compute, predict(outcome(`i')) var(prof pblack phisp plunch gravg_adj ptr middle)
	mat myb=e(Xmfx_dydx)
	mat myb=myb[1...,1..7]
	mat myV=diag(e(Xmfx_se_dydx))
	mat myV=myV*myV
	mat myV=myV[1..7,1..7]
	local obs=e(N)
	ereturn post myb myV, obs(`obs')
	if `i'==1 {
	outreg2 prof pblack phisp plunch gravg_adj ptr middle using Out/tableA1, excel noaster nocons br bdec(3) sdec(3) replace ctitle("C`j'`i'")
	}
	if `i'~=1 {
	outreg2 prof pblack phisp plunch gravg_adj ptr middle using Out/tableA1, excel noaster nocons br bdec(3) sdec(3) ctitle("C`j'`i'")
	}
}

*Get share each grade to put in Table A1
tab rate4 [iweight=weight1]

*TABLE A2 - Descriptive Statistics, By Whether Respondent Identified Local Elementary and Middle Schools
use national_file.dta, clear

keep caseid age male black hisp inc college parent617 own q6 q8 weight1
duplicates drop

gen noelem = (q6==-1 | q6==6)
gen nomidd = (q8==-1 | q8==6)
gen know = 0 if noelem==1 & nomidd==1
replace know = 2 if noelem==0 & nomidd==0
recode know .=1

*For significant tests in Table A2
xi i.know
for any age male black hisp inc college parent617 own: reg X _Iknow* [weight=weight1]

*For discussion in text
reg know age male black hisp inc college parent617 own

*Bottom row of Table A2
tab know [iweight=weight1]

save temp, replace
*First col of Table A2
collapse (count) caseid (mean) age male black hisp inc college parent617 own [weight=weight1]
outsheet using Out/tableA2_col1.xls, replace

*Col 2-4 of Table A2
use temp, clear
collapse (count) caseid (mean) age male black hisp inc college parent617 own [weight=weight1], by(know)
outsheet using Out/tableA2_col24.xls, replace
erase temp.dta

*FIGURE 1 - code to create data file that is used to make figure in R

use national_file.dta, clear

gen profpar617 = prof*parent617

quietly tab STABBR, gen(sdum)
drop sdum1 sdum37

*Install Clarify package if not already installed
*net from http://gking.harvard.edu/clarify
*net install clarify

estsimp reg rate4 prof profpar617 parent617 pblack phisp plunch gravg_adj ptr middle sdum* [aweight=weight1], cluster(caseid) sims(5000)

foreach i of numlist 0/100 {
setx (prof profpar617) `i'/10 parent617 1 (pblack phisp plunch gravg_adj ptr middle sdum2-sdum51) mean
simqi, genev(evpa`i')
setx prof `i'/10 (profpar617 parent617) 0 (pblack phisp plunch gravg_adj ptr middle sdum2-sdum51) mean
simqi, genev(evnp`i')
gen sdpa`i' = evpa`i'
gen sdnp`i' = evnp`i'
gen fd`i' = evpa`i'-evnp`i'
gen sdfd`i' = fd`i'
}

collapse (mean) evpa* evnp* fd* (sd) sdpa* sdnp* sdfd*
gen p = 1
reshape long evpa evnp fd sdpa sdnp sdfd, i(p) j(n)

drop p
ren n prof

gen p05pa = evpa-1.96*sdpa
gen p95pa = evpa+1.96*sdpa
gen p05np = evnp-1.96*sdnp
gen p95np = evnp+1.96*sdnp
gen p05fd = fd-1.96*sdfd
gen p95fd = fd+1.96*sdfd

save forRfig, replace

*ANALYSIS OF FLORIDA DATASET (TABLES 3, 4, 5, A3, A4)
use florida_file, clear

*Divide variables by their standard deviation so that coefficients will corresponding to one-sd change in independent variable
sum pointsL_avg3 [aweight=weight4]
gen pointsL3 = pointsL_avg3/r(sd)
sum pointsG_avg3 [aweight=weight4]
gen pointsG3 = pointsG_avg3/r(sd)

foreach v in pblack phisp plunch gravg_adj ptr {
sum `v' [aweight=weight4] if pblack~=. & ptr~=. & pointsL3~=.
replace `v' = `v'/r(sd)
}

*Generate interaction terms
gen gr08par = gr084*parent617
gen ptsL3par = pointsL3*parent617
gen ptsG3par = pointsG3*parent617

*TABLE 3 - Relationship Between Test-Score Levels/Growth and Respondents' School Ratings, Florida
reg rate4 pointsL3 pointsG3 pblack phisp plunch gravg_adj ptr middle high [aweight=weight4], cluster(caseid)
outreg2 using Out/table3, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
test pointsL3=pointsG3
areg rate4 pointsL3 pointsG3 pblack phisp plunch gravg_adj ptr middle high [aweight=weight4], absorb(caseid) cluster(caseid)
outreg2 using Out/table3, excel br noaster bdec(3) sdec(3) rdec(3) nocons
test pointsL3=pointsG3
reg rate4 pointsL3 pointsG3 pblack phisp plunch gravg_adj ptr middle high parent617 ptsL3par ptsG3par [aweight=weight4], cluster(caseid)
outreg2 using Out/table3, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 pointsL3 pointsG3 pblack phisp plunch gravg_adj ptr middle high ptsL3par ptsG3par [aweight=weight4], absorb(caseid) cluster(caseid)
outreg2 using Out/table3, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*TABLE 4 - Relationship Between School Grades and Respondents' School Ratings, Florida
reg rate4 gr084 pblack phisp plunch gravg_adj ptr middle high [aweight=weight4], cluster(caseid)
outreg2 gr084 using Out/table4, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
areg rate4 gr084 pblack phisp plunch gravg_adj ptr middle high [aweight=weight4], absorb(caseid) cluster(caseid)
outreg2 gr084 using Out/table4, excel br noaster bdec(3) sdec(3) rdec(3) nocons
xi i.gr08
reg rate4 _Igr* pblack phisp plunch gravg_adj ptr middle high [aweight=weight4], cluster(caseid)
outreg2 _Igr* using Out/table4, excel br noaster bdec(3) sdec(3) rdec(3) nocons
areg rate4 _Igr* pblack phisp plunch gravg_adj ptr middle high [aweight=weight4], absorb(caseid) cluster(caseid)
outreg2 _Igr* using Out/table4, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*RD ANALYSIS OF B-C CUTOFF
use florida_RD_BC, clear

*TABLE 5 (TOP PANEL) - Regression Discontinuity Estimates of Accountability Grade Effect on Respondent Ratings
reg rate4 grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=15 & BCpoints>=-15, cluster(caseid)
outreg2 grB BCpoints grB_BCpnts using Out/table5_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
reg rate4 grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=20 & BCpoints>=-20, cluster(caseid)
outreg2 grB BCpoints grB_BCpnts using Out/table5_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=25 & BCpoints>=-25, cluster(caseid)
outreg2 grB BCpoints grB_BCpnts using Out/table5_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*TABLE A3 (TOP PANEL) - Regression Discontinuity Estimates of Accountability Grade Effect on Respondent Characteristics
reg parent617 grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=15 & BCpoints>=-15, cluster(caseid)
outreg2 grB using Out/tableA3_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
reg parent617 grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=20 & BCpoints>=-20, cluster(caseid)
outreg2 grB using Out/tableA3_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg parent617 grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=25 & BCpoints>=-25, cluster(caseid)
outreg2 grB using Out/tableA3_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons

foreach v in own black hisp college male lninc {
	reg `v' grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=15 & BCpoints>=-15, cluster(caseid)
	outreg2 grB using Out/tableA3_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
	reg `v' grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=20 & BCpoints>=-20, cluster(caseid)
	outreg2 grB using Out/tableA3_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
	reg `v' grB BCpoints grB_BCpnts middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpoints<=25 & BCpoints>=-25, cluster(caseid)
	outreg2 grB using Out/tableA3_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
}

*TABLE A4 (TOP PANEL) - Regression Discontinuity Estimates of Accountability Grade Effect on Respondent Ratings, False Cutoffs
*Increase cutoff by 15 points
gen BCpointsf = BCpoints+15
gen grBf = (BCpointsf>=0)
gen grB_BCpntsf = grBf*BCpointsf

reg rate4 grBf BCpointsf grB_BCpntsf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpointsf<=15 & BCpointsf>=-15, cluster(caseid)
outreg2 grBf using Out/tableA4_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
reg rate4 grBf BCpointsf grB_BCpntsf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpointsf<=20 & BCpointsf>=-20, cluster(caseid)
outreg2 grBf using Out/tableA4_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 grBf BCpointsf grB_BCpntsf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpointsf<=25 & BCpointsf>=-25, cluster(caseid)
outreg2 grBf using Out/tableA4_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*Decrease cutoff by 15 points
drop BCpointsf grBf grB_BCpntsf
gen BCpointsf = BCpoints-15
gen grBf = (BCpointsf>=0)
gen grB_BCpntsf = grBf*BCpointsf

reg rate4 grBf BCpointsf grB_BCpntsf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpointsf<=15 & BCpointsf>=-15, cluster(caseid)
outreg2 grBf using Out/tableA4_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 grBf BCpointsf grB_BCpntsf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpointsf<=20 & BCpointsf>=-20, cluster(caseid)
outreg2 grBf using Out/tableA4_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 grBf BCpointsf grB_BCpntsf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if BCpointsf<=25 & BCpointsf>=-25, cluster(caseid)
outreg2 grBf using Out/tableA4_BC, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*RD ANALYSIS OF ALL CUTOFFS POOLED
use florida_RD_pooled, clear

*TABLE 5 (MIDDLE AND BOTTOM PANELS) - Regression Discontinuity Estimates of Accountability Grade Effect on Respondent Ratings
reg rate4 RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=15 & RDpoints>=-15, cluster(caseid)
outreg2 RDgr RDpoints RDinteract using Out/table5_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
reg rate4 RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=20 & RDpoints>=-20, cluster(caseid)
outreg2 RDgr RDpoints RDinteract using Out/table5_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=25 & RDpoints>=-25, cluster(caseid)
outreg2 RDgr RDpoints RDinteract using Out/table5_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons

reg rate4 RDgr RDpoints RDinteract parent_inter parent617 middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=15 & RDpoints>=-15, cluster(caseid)
outreg2 RDgr RDpoints RDinteract parent_inter parent617 using Out/table5_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 RDgr RDpoints RDinteract parent_inter parent617 middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=20 & RDpoints>=-20, cluster(caseid)
outreg2 RDgr RDpoints RDinteract parent_inter parent617 using Out/table5_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 RDgr RDpoints RDinteract parent_inter parent617 middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=25 & RDpoints>=-25, cluster(caseid)
outreg2 RDgr RDpoints RDinteract parent_inter parent617 using Out/table5_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*TABLE A3 (BOTTOM PANEL) - Regression Discontinuity Estimates of Accountability Grade Effect on Respondent Characteristics
reg parent617 RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=15 & RDpoints>=-15, cluster(caseid)
outreg2 RDgr using Out/tableA3_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
reg parent617 RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=20 & RDpoints>=-20, cluster(caseid)
outreg2 RDgr using Out/tableA3_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg parent617 RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=25 & RDpoints>=-25, cluster(caseid)
outreg2 RDgr using Out/tableA3_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons

foreach v in own black hisp college male lninc {
	reg `v' RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=15 & RDpoints>=-15, cluster(caseid)
	outreg2 RDgr using Out/tableA3_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
	reg `v' RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=20 & RDpoints>=-20, cluster(caseid)
	outreg2 RDgr using Out/tableA3_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
	reg `v' RDgr RDpoints RDinteract middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpoints<=25 & RDpoints>=-25, cluster(caseid)
	outreg2 RDgr using Out/tableA3_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
}

*TABLE A4 (BOTTOM PANEL) - Regression Discontinuity Estimates of Accountability Grade Effect on Respondent Ratings, False Cutoffs
*Increase cutoff by 15 points
gen RDpointsf = RDpoints+15
gen RDgrf = (RDpointsf>=0)
gen RDinteractf = RDgrf*RDpointsf

reg rate4 RDgrf RDpointsf RDinteractf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpointsf<=15 & RDpointsf>=-15, cluster(caseid)
outreg2 RDgrf using Out/tableA4_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons replace
reg rate4 RDgrf RDpointsf RDinteractf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpointsf<=20 & RDpointsf>=-20, cluster(caseid)
outreg2 RDgrf using Out/tableA4_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 RDgrf RDpointsf RDinteractf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpointsf<=25 & RDpointsf>=-25, cluster(caseid)
outreg2 RDgrf using Out/tableA4_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons

*Decrease cutoff by 15 points
drop RDpointsf RDgrf RDinteractf
gen RDpointsf = RDpoints-15
gen RDgrf = (RDpointsf>=0)
gen RDinteractf = RDgrf*RDpointsf

reg rate4 RDgrf RDpointsf RDinteractf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpointsf<=15 & RDpointsf>=-15, cluster(caseid)
outreg2 RDgrf using Out/tableA4_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 RDgrf RDpointsf RDinteractf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpointsf<=20 & RDpointsf>=-20, cluster(caseid)
outreg2 RDgrf using Out/tableA4_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
reg rate4 RDgrf RDpointsf RDinteractf middle high phisp pblack plunch gravg_adj ptr [aweight=weight4] if RDpointsf<=25 & RDpointsf>=-25, cluster(caseid)
outreg2 RDgrf using Out/tableA4_pool, excel br noaster bdec(3) sdec(3) rdec(3) nocons
